{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2015-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends config.THEME_ERROR_TEMPLATE %}

{% block message %}
  <h1><i class="fa fa-flash"></i> {{_('Unauthorized')}}</h1>
  <p>{{_('You need to be authenticated to view this page.')}}</p>
{% endblock message %}
